<?php
/**
 * Plugin Name: Take Notice
 * Plugin URI: http://alisothegeek.com/wordpress-plugins/take-notice/
 * Description: Add a site-wide message to your blog that displays on every post and/or page.
 * Version: 1.0
 * Author: Alison Barrett
 * Author URI: http://alisothegeek.com/
 * License: GPLv2
 * 
 * Copyright 2011  Alison Barrett (email : alison@barrettcreative.net)
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2, as 
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/**
 * @package take-notice
 * @since 1.0
 */
class Take_Notice {
	
	/**
	 * server path to plugin folder
	 *
	 * @var string
	 * @since 1.0
	 */
	public $dir;
	
	/**
	 * Construct
	 *
	 * @since 1.0
	 */
	public function __construct() {
		
		$this->dir = plugin_dir_path( __FILE__ );
		$this->wp_hooks();
		
	}
	
	/**
	 * Add all notices to content
	 *
	 * @since 1.0
	 */
	public function add_to_content( $content ) {
		
		if ( ( is_single() || is_page() ) && ! is_front_page() ) :
		
			$notices = get_posts( 'post_type=notice&posts_per_page=-1' );
			foreach ( $notices as $notice ) :
				
				$notice_content = wpautop( wptexturize( $notice->post_content ) );
				
				$show_on = get_post_meta( $notice->ID, '_takenotice_show_on' );
				$show_at = get_post_meta( $notice->ID, '_takenotice_show_at', true );
				$show_title = get_post_meta( $notice->ID, '_takenotice_show_title', true );
				$notice_color = get_post_meta( $notice->ID, '_takenotice_color', true );
				
				if ( $show_title )
					$notice_content = '<h1>' . $notice->post_title . '</h1>' . $notice_content;
				
				if ( is_single() ) {
					if ( in_array( 'posts', $show_on ) ) {
						
						if ( $show_at == 'top' )
							$content = '<div class="take-notice ' . $notice_color . '">' . $notice_content . '</div>' . $content;
						elseif ( $show_at == 'bottom' )
							$content .= '<div class="take-notice ' . $notice_color . '">' . $notice_content . '</div>';
						
					}
				}
				else {
					if ( in_array( 'pages', $show_on ) ) {
						
						if ( $show_at == 'top' )
							$content = '<div class="take-notice ' . $notice_color . '">' . $notice_content . '</div>' . $content;
						elseif ( $show_at == 'bottom' )
							$content .= '<div class="take-notice ' . $notice_color . '">' . $notice_content . '</div>';
						
					}
				}
				
			endforeach;
			
			return $content;
		
		else :
		
			return $content;
		
		endif;
		
	}
	
	/**
	 * Add meta box for notice post type
	 *
	 * @since 1.0
	 */
	public function notice_meta_box() {
		
		if ( is_admin() ) {
			
			require_once( $this->dir . 'class-rw-meta-box.php' );
			$prefix = '_takenotice_';
			$meta_box = array(
				'id' => 'takenotice-meta-box',
				'title' => 'Notice Details',
				'pages' => array( 'notice' ), // custom post types, since WordPress 3.0
				'context' => 'normal',
				'priority' => 'high',
				'fields' => array(
					array(
						'name' => 'Show on',
						'desc' => '',
						'id' => $prefix . 'show_on',
						'type' => 'checkbox_list',
						'options' => array(
							'posts' => 'Posts',
							'pages' => 'Pages'
						)
					),
					array(
						'name' => 'Position in post',
						'desc' => '',
						'id' => $prefix . 'show_at',
						'type' => 'select',
						'options' => array(
							'top' => 'Above content',
							'bottom' => 'Below content'
						)
					),
					array(
						'name' => 'Show title',
						'desc' => 'Show title of notice',
						'id' => $prefix . 'show_title',
						'type' => 'checkbox'
					),
					array(
						'name' => 'Color',
						'desc' => '',
						'id' => $prefix . 'color',
						'type' => 'select',
						'options' => array(
							'grey' => 'Grey',
							'red' => 'Red',
							'yellow' => 'Yellow',
							'green' => 'Green',
							'blue' => 'Blue'
						)
					)
				)
			);
			
			$notice_meta_box = new RW_Meta_Box( $meta_box );
			
		}
		
	}
	
	/**
	 * Register post type
	 *
	 * @since 1.0
	 */
	public function register_post_type() {
		
		register_post_type( 'notice', array(
			'labels' => array(
				'name' => __( 'Notices' ),
				'singular_name' => __( 'Notice' ),
				'add_new' => __( 'Add New' ),
				'add_new_item' => __( 'Add New Notice' ),
				'edit_item' => __( 'Edit Notice' ),
				'new_item' => __( 'New Notice' ),
				'view_item' => __( 'View Notice' ),
				'search_items' => __( 'Search Notices' ),
				'not_found' => __( 'No notices found' ),
				'not_found_in_trash' => __( 'No notices found in Trash' ), 
				'parent_item_colon' => __( 'Parent Notice:' ),
				'menu_name' => __( 'Notices' )
			),
			'public' => true,
			'publicly_queryable' => true,
			'show_ui' => true, 
			'show_in_menu' => true, 
			'query_var' => true,
			'rewrite' => array( 'slug' => 'notice' ),
			'capability_type' => 'post',
			'has_archive' => true, 
			'hierarchical' => false,
			'menu_position' => null,
			'menu_icon' => plugins_url( '', __FILE__ ) . '/sticky-note-pin.png',
			'supports' => array( 'title', 'editor', 'author' )
		) );
		
	}
	
	/**
	 * Add stylesheet
	 *
	 * @since 1.0
	 */
	public function register_styles() {
		
		if ( ( is_single() || is_page() ) && ! is_front_page() ) {
			wp_register_style( 'take-notice', plugins_url( '', __FILE__ ) . '/style.css' );
			wp_enqueue_style( 'take-notice' );
		}
		
	}
	
	/**
	 * WordPress hooks & filters
	 *
	 * @since 1.0
	 */
	public function wp_hooks() {
		
		add_action( 'init',            array( &$this, 'register_post_type' ) );
		add_action( 'init',            array( &$this, 'notice_meta_box' ) );
		add_action( 'wp_print_styles', array( &$this, 'register_styles' ) );
		add_filter( 'the_content',     array( &$this, 'add_to_content' ), 1, 1 );
		
	}
	
}

if ( class_exists( 'Take_Notice' ) )
	$Take_Notice = new Take_Notice();

?>